@@ -4,7 +4,7 @@ use 5.008003;
 use strict;
 use warnings;
 
-our $VERSION = '1.63';
+our $VERSION = '1.64';
 
 use XSLoader;
 XSLoader::load( 'Audio::TagLib', $VERSION );
@@ -76,6 +76,7 @@ __END__
 =pod
 
 =begin stopwords
+
 Ogg
 FLAC
 MPC
@@ -94,6 +95,7 @@ param
 AudioProperties
 READONLY
 Dongxu
+
 =end stopwords
 
 =head1 NAME
@@ -125,7 +127,7 @@ between tag and file formats can all be ignored.
 
 =head1 VERSION
 
-1.63
+1.64
 
 =head1 DESCRIPTION
 
@@ -218,7 +220,7 @@ I<DESTROY()>.
 =head1 SEE ALSO
 
 The TagLib documentation page.
-http://developer.kde.org/~wheeler/taglib.html
+http://taglib.github.io/
 
 =head1 KNOWN BUGS
 
@@ -237,6 +239,8 @@ Sisyphus sisyphus@cpan.org
 
 CHOCOLATE choclate@cpan.org
 
+Philip Lyons vorzox@gmail.com
+
 =head1 AUTHOR
 
 Dongxu Ma dongxu@cpan.org
@@ -249,7 +253,7 @@ Geoffrey Leach GLEACH@cpan.org
 
 Copyright (C) 2005 - 2010 by Dongxu Ma
 
-Copyright (C) 2011 - 2012 Geoffrey Leach
+Copyright (C) 2011 - 2013 Geoffrey Leach
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
